{% load static %}
{% load aa_customizer_tags %}

{# If a custom favicon has been uploaded, use it exclusively.                  #}
{# Otherwise fall back to the default Alliance Auth icon set.                  #}
{% customizer_favicon_tags as custom_favicons %}
{% if custom_favicons %}
    {{ custom_favicons }}
{% else %}
    <link rel="apple-touch-icon" sizes="180x180" href="{% static 'allianceauth/icons/apple-touch-icon.png' %}">
    <link rel="icon" type="image/png" href="{% static 'allianceauth/icons/favicon-16x16.png' %}" sizes="16x16">
    <link rel="icon" type="image/png" href="{% static 'allianceauth/icons/favicon-32x32.png' %}" sizes="32x32">
    <link rel="icon" type="image/png" href="{% static 'allianceauth/icons/favicon-96x96.png' %}" sizes="96x96">
    <link rel="manifest" href="{% static 'allianceauth/icons/site.webmanifest' %}">
    <link rel="mask-icon" href="{% static 'allianceauth/icons/safari-pinned-tab.svg' %}" color="#5bbad5">
    <link rel="shortcut icon" type="image/png" href="{% static 'allianceauth/icons/favicon.ico' %}">

    <meta name="msapplication-TileColor" content="#2d89ef">
    <meta name="msapplication-config" content="{% static 'allianceauth/icons/browserconfig.xml' %}">
    <meta name="theme-color" content="#ffffff">
{% endif %}
