# Generated by Django 6.0.3 on 2026-03-21 22:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_customizer', '0009_aacmediaimage_library_fk_fields'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aacmediaimage',
            name='image_type',
            field=models.CharField(choices=[('any', 'Any / General'), ('background', 'Background'), ('logo', 'Logo'), ('icon', 'Icon / Favicon')], default='any', help_text='Optional category for organisation — does not restrict usage.', max_length=20, verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='aacmediaimage',
            name='name',
            field=models.CharField(help_text="A descriptive label for this image, e.g. 'Corp logo v2' or 'Winter background'.", max_length=100, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='favicon_library',
            field=models.ForeignKey(blank=True, help_text='Select an image from the media library. Takes priority over a direct upload; a URL takes priority over both.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='aa_customizer.aacmediaimage', verbose_name='Favicon — Library'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='login_background_library',
            field=models.ForeignKey(blank=True, help_text='Select an image from the media library. Takes priority over a direct upload; a URL takes priority over both.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='aa_customizer.aacmediaimage', verbose_name='Login Background — Library'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='login_background_url',
            field=models.URLField(blank=True, help_text='URL of a background image or video file (e.g. a CDN, Imgur, or object-storage link). Takes priority over an uploaded file. Ideal for Docker installs. Supported video formats: .mp4, .webm, .ogv. Note: YouTube and other streaming links are not supported — the URL must point directly to a file.', verbose_name='Login Background — URL'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='login_logo_library',
            field=models.ForeignKey(blank=True, help_text='Select an image from the media library. Takes priority over a direct upload; a URL takes priority over both.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='aa_customizer.aacmediaimage', verbose_name='Login Logo — Library'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='navbar_logo_library',
            field=models.ForeignKey(blank=True, help_text='Select an image from the media library. Takes priority over a direct upload; a URL takes priority over both.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='aa_customizer.aacmediaimage', verbose_name='Navbar Logo — Library'),
        ),
        migrations.AlterField(
            model_name='custombranding',
            name='sidebar_logo_library',
            field=models.ForeignKey(blank=True, help_text='Select an image from the media library. Takes priority over a direct upload; a URL takes priority over both.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='aa_customizer.aacmediaimage', verbose_name='Sidebar Logo — Library'),
        ),
    ]
