# Generated by Django 6.0.3 on 2026-03-22 21:23

import aa_customizer.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_customizer', '0011_custombranding_video_loop_count'),
    ]

    operations = [
        migrations.AlterField(
            model_name='custombranding',
            name='login_background',
            field=models.FileField(blank=True, help_text='Upload a background image or video for the login page. Images: JPEG, PNG, GIF, WebP (recommended: at least 1920×1080 px). Videos: MP4, WebM, OGV. Ignored when a URL is also provided.', null=True, upload_to='aa_customizer/backgrounds/', validators=[aa_customizer.models.validate_image_or_video], verbose_name='Login Background — Upload'),
        ),
    ]
