# Generated by Django 4.2.29 on 2026-03-21 00:59

from django.db import migrations


class Migration(migrations.Migration):
    """
    Merge migration resolving the two parallel 0003 migrations:
    - 0003_alter_custombranding_custom_css_and_more (help_text/verbose_name updates)
    - 0003_restore_change_view_permissions (restores change/view permissions)
    """

    dependencies = [
        ('aa_customizer', '0003_alter_custombranding_custom_css_and_more'),
        ('aa_customizer', '0003_restore_change_view_permissions'),
    ]

    operations = [
    ]
